# Contributors

* Yuliia Pavliuk ([@pav.yulia](https://crowdin.com/profile/pav.yulia))
* Steven Silvester ([@blink1073](https://crowdin.com/profile/blink1073))
* JupyterLab Bot ([@jupyterlab-bot](https://crowdin.com/profile/jupyterlab-bot))
* Alina ([@astromavka](https://crowdin.com/profile/astromavka))
* Denys ([@Veydzher](https://crowdin.com/profile/Veydzher))
* seventeenfive36 ([@seventeenfive36](https://crowdin.com/profile/seventeenfive36))
* Vladyslav Sazhen ([@astrochumak](https://crowdin.com/profile/astrochumak))
* Valentyna_Boberska ([@Valentyna_Boberska](https://crowdin.com/profile/Valentyna_Boberska))
* EvelinaRevenko ([@EvelinaRevenko](https://crowdin.com/profile/EvelinaRevenko))
* khrystynaboitsun ([@khrystynaboitsun](https://crowdin.com/profile/khrystynaboitsun))
* Oleksii Burdin ([@oleksiburdin](https://crowdin.com/profile/oleksiburdin))
* sahanshiii ([@sahanshiii](https://crowdin.com/profile/sahanshiii))
* Nathalie Rud ([@talka](https://crowdin.com/profile/talka))
* lodka ([@lodka](https://crowdin.com/profile/lodka))
* Olia Tkachuk ([@ms_lechka](https://crowdin.com/profile/ms_lechka))
* Serhiy Dmytryshyn ([@dies](https://crowdin.com/profile/dies))
* d.yankovskyi ([@d.yankovskyi](https://crowdin.com/profile/d.yankovskyi))
